@@ -52,35 +52,43 @@ test_that("validationType = 'TVH' option", {
 
 
 test_that("validationType = 'CV' option can be used to SetTarget", {
-  with_mock("GetProjectStatus" = function(...) { list("stage" = ProjectStage$AIM) },
-            "datarobot::DataRobotPATCH" = function(...) {
-              list(...) # Resolve params to test that they pass without error
-            },
-            "datarobot::WaitForAsyncReturn" = function(...) { "How about not" }, {
-    groupPartition <- CreateGroupPartition(validationType = "CV",
-                                           holdoutPct = 20,
-                                           partitionKeyCols = list("tax"),
-                                           reps = 5)
-    SetTarget(project = fakeProject,
-              target = fakeTarget,
-              partition = groupPartition)
-  })
+  with_mocked_bindings(
+    GetProjectStatus = function(...) { list("stage" = ProjectStage$AIM) },
+    {
+      groupPartition <- CreateGroupPartition(validationType = "CV",
+                                             holdoutPct = 20,
+                                             partitionKeyCols = list("tax"),
+                                             reps = 5)
+      SetTarget(project = fakeProject,
+                target = fakeTarget,
+                partition = groupPartition)
+    },
+    DataRobotPATCH = function(...) {
+      list(...) # Resolve params to test that they pass without error
+    },
+    WaitForAsyncReturn = function(...) { "How about not" },
+    .package = "datarobot"
+  )
 })
 
 test_that("validationType = 'TVH' option can be used to SetTarget", {
-  with_mock("GetProjectStatus" = function(...) { list("stage" = ProjectStage$AIM) },
-            "datarobot::DataRobotPATCH" = function(...) {
-              list(...) # Resolve params to test that they pass without error
-            },
-            "datarobot::WaitForAsyncReturn" = function(...) { "How about not" }, {
-    groupPartition <- CreateGroupPartition(validationType = "TVH",
-                                           partitionKeyCols = list("tax"),
-                                           holdoutPct = 20,
-                                           validationPct = 16)
-    SetTarget(project = fakeProject,
-              target = fakeTarget,
-              partition = groupPartition)
-  })
+  with_mocked_bindings(
+    GetProjectStatus = function(...) { list("stage" = ProjectStage$AIM) },
+    {
+      groupPartition <- CreateGroupPartition(validationType = "TVH",
+                                             partitionKeyCols = list("tax"),
+                                             holdoutPct = 20,
+                                             validationPct = 16)
+      SetTarget(project = fakeProject,
+                target = fakeTarget,
+                partition = groupPartition)
+    },
+    DataRobotPATCH = function(...) {
+      list(...) # Resolve params to test that they pass without error
+    },
+    WaitForAsyncReturn = function(...) { "How about not" },
+    .package = "datarobot"
+  )
 })
 
 
